


#' Create an object of class "myptf"
#' 
#' Create a portfolio with information on quantities (composition) and
#' prices.
#'
#' @param ptfcode alpha-numeric identification string.
#' @param ptfname full name of the portfolio.
#' @param prices object of class \code{timeSeries} with assets prices.
#' @param quantities object of class \code{timeSeries} with assets quantities.
#' @param currency currency used.
#'
#' @return object of classs \code{myptf}, structured in a \code{list} with the
#' following components:
#' \describe{
#'   \item{\code{code}}{alpha-numeric identification string.}
#'   \item{\code{name}}{complete name of the portfolio.}
#'   \item{\code{prices}}{multivariate \code{timeSeries} of asset prices.}
#'   \item{\code{quantities}}{multivariate \code{timeSeries} of asset quantities.}
#'   \item{\code{currency}}{currency string code.}
#' }
#'
#' @seealso \code{\link[timeSeries]{timeSeries}} function of
#' \code{\link[timeSeries]{timeSeries-package}}.
#'
#' @examples
#' # load dataset "stockPrices"
#' data(stockPrices)
#' # set portfolio composition
#' quant<- data.frame(Date=c('2016-03-01','2017-02-07'),
#'   ENI=c(100,120),FCA=c(200,250),UCG=c(230,160))
#' quant
#' # create portfolio
#' ptfA<- myptf('PTFA','Portfolio A',stockPrices,quant)
#' ptfA
#'
#' @export
myptf<- function(ptfcode,ptfname=ptfcode,prices=NULL,quantities=NULL,currency='EUR') {
  if (!is.timeSeries(prices)) {
  	stop('Object of class "timeSeries" required for argument "prices"')
  }
  
  if (!is.null(quantities)) {
    if (!is.timeSeries(quantities)) { quantities<- as.timeSeries(quantities) }
    if (ncol(quantities)!=ncol(prices)) {
      stop('Numbers of columns of "prices" and "quantities" do not correspond')
    }
  }
  
  out<- list(code=as.character(ptfcode),
             name=as.character(ptfname),
             prices=prices,
             quantities=quantities,
             currency=as.character(currency))
  class(out)<- 'myptf'
  out
}



#' Print method for class "myptf"
#' 
#' Print an object of class \code{\link{myptf}}.
#'
#' @inheritParams base::print.default
#'
#' @seealso \code{\link{myptf}}
#'
#' @method print myptf
#' @export
print.myptf<- function(x,...) {
  cat(paste0(rep('-',50),collapse=''),'\n')
  cat(' Object of class "myptf"\n')
  cat(paste0(rep('-',50),collapse=''),'\n')
  cat(' Code             :',x$code,'\n')
  cat(' Name             :',x$name,'\n')
  cat(' Number of assets :',ncol(x$prices),'\n')
  cat(' Currency         :',x$currency,'\n')
  cat(' Current value    :',round(get_value(x),2),x$currency,'\n')
  cat(paste0(rep('-',50),collapse=''),'\n')
  cat('\n')
}




